Type Alias Index2
Source pub type Index2<'a> = TableRef<'a, Index2Marker>;
An array of variable-sized objects in a CFF2 table.
pub struct Index2<'a> {
pub(crate) shape: Index2Marker,
pub(crate) data: FontData<'a>,
}
Returns the total size in bytes of the index table.
Returns the offset of the object at the given index.
Returns the data for the object at the given index.
Number of objects stored in INDEX.
Object array element size.
Bytes containing count + 1 offsets each of off_size.
Array containing the object data.
Read an instance of
Self from the provided data, performing validation.
Read more